@@ -1,7 +1,7 @@
 package Module::FatPack;
 
 our $DATE = '2016-12-28'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -186,6 +186,7 @@ _
         push @res, '    $main::fatpacked{"', $mod_pm, '"} = \'' . $line_prefix . q|#line '.(1+__LINE__).' "'.__FILE__."\"\n".<<'|, $label, "';\n";
         $module_srcs{$mod_pm} =~ s/^/$line_prefix/gm;
         push @res, $module_srcs{$mod_pm};
+        push @res, "\n" unless $module_srcs{$mod_pm} =~ /\R\z/;
         push @res, "$label\n\n";
     }
     if ($pm) {
@@ -203,27 +204,29 @@ _
 #_
 
     my $hook_src = <<'_';
-    if ($] < 5.008) {
-        *{"${class}::INC"} = sub {
-            if (my $fat = $_[0]{$_[1]}) {
-                return sub {
-                    return 0 unless length $fat;
-                    $fat =~ s/^([^\n]*\n?)//;
-                    $_ = $1;
-                    return 1;
-                };
-            }
-            return;
-        };
-    } else {
-        *{"${class}::INC"} = sub {
-            if (my $fat = $_[0]{$_[1]}) {
-                open my $fh, '<', \$fat
-                    or die "FatPacker error loading $_[1] (could be a perl installation issue?)";
-                return $fh;
-            }
-            return;
-        };
+    unless (defined &{"${class}::INC"}) {
+        if ($] < 5.008) {
+            *{"${class}::INC"} = sub {
+                if (my $fat = $_[0]{$_[1]}) {
+                    return sub {
+                        return 0 unless length $fat;
+                        $fat =~ s/^([^\n]*\n?)//;
+                        $_ = $1;
+                        return 1;
+                    };
+                }
+                return;
+            };
+        } else {
+            *{"${class}::INC"} = sub {
+                if (my $fat = $_[0]{$_[1]}) {
+                    open my $fh, '<', \$fat
+                        or die "FatPacker error loading $_[1] (could be a perl installation issue?)";
+                    return $fh;
+                }
+                return;
+            };
+        }
     }
 _
     if ($pm) { $hook_src =~ s/\R\s+/ /g }
@@ -275,7 +278,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.14 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-12-28.
+This document describes version 0.15 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-12-28.
 
 =head1 FUNCTIONS
 
